import{d,r as i,o as l,a3 as u,b as c,c as f,N as y,ad as m}from"./registerWidgets.bbbd3e16.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4a59e57e-d6f3-4c92-90e3-54987e502e75",e._sentryDebugIdIdentifier="sentry-dbid-4a59e57e-d6f3-4c92-90e3-54987e502e75")}catch{}})();const g=d({__name:"ActionButton",props:{action:null},emits:["next"],setup(e,{emit:n}){const o=e,s=i(null);l(()=>{s.value&&o.action.setElement(s.value),u.addAction(o.action)});const a=()=>n("next");return(p,t)=>(c(),f("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=r=>a()),onKeydown:t[1]||(t[1]=m(r=>a(),["enter"]))},y(e.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.e3c03d38.js.map
