import{x as s}from"./icons.3f47812d.js";import{d as c,a as r,b as i,c as d,e as _,z as l,S as f,q as u}from"./registerWidgets.bbbd3e16.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f65afebc-bc2a-4536-9703-a97cd7b42e82",e._sentryDebugIdIdentifier="sentry-dbid-f65afebc-bc2a-4536-9703-a97cd7b42e82")}catch{}})();const b=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),f(" Editor ")])}}});const w=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.706cbdd4.js.map
